## D-Analyst : High Performance Visualization Tool
--------------------------------------------------
D-Analyst is a high performance data visualization built with python and based on OpenGL.
It allows to interactively visualize very large plot consisitng of up to millions of data in real time.

D-Analyst high-level interface is inspired by Matplotlib, Seaborns and Plotly.
The low-level interface can be used to write complex interactive visualization
GUIs with Qt that deal with large 2D/3D datasets.

This tools visualization potentials goes beyond plots. It is built to include textures, 3D meshes, shapes and graphs.
It also allows you to write custom shaders for advanced uses.

## Installation
-----------------


## Usage
---------


## Support
----------
For assistance in using this great visualization tool, send an email to the head of the development team at `adeoluwaagbakosi@gmail.com`.

## Contributing
-----------------
Pull request are welcome. For major changes, please open an issue first to discuss what you would like to change.

For more information and guidelines on contributing check out [CONTRIBUTING.md](./CONTRIBUTING.md).

## Code Of Conduct
------------------
The Diachronic Community requires its members to abide by the [Code Of Conduct](./CODE_OF_CONDUCT.md). In this CoC you will find the expectations of members, the penalties for violating these expectations, and how violations can be reported to the members of the community in charge of enforcing this Code of Conduct.

## License
----------
This project is Licensed under the terms of the MIT Liscense.
For more information [LICENSE.txt](./LICENSE.txt).